@@ -3,6 +3,7 @@ import decimal
 from typing import TYPE_CHECKING, Generic, List, Optional, TypeVar, Union
 
 from django.contrib.auth.models import AbstractUser, AnonymousUser
+from django.core.exceptions import ImproperlyConfigured
 from django.db import models
 from django.db.models import Prefetch
 from django.db.models.fields import NOT_PROVIDED
@@ -26,7 +27,7 @@ from .perms import check_authenticated, check_perms
 from .schema import FieldKind, get_field_schema
 from .utils import get_model_fields, update_dict_nested
 
-if TYPE_CHECKING:
+if TYPE_CHECKING:  # pragma: nocover
     _BaseDjangoObjectType = DjangoObjectType
 
 _T = TypeVar("_T", bound=models.Model)
@@ -52,9 +53,9 @@ def schema_for_field(field, name):
     else:
         required = not field.blank and field.default is NOT_PROVIDED
 
-    if getattr(field, "choices", None):
-        items = field.choices
-        if isinstance(items, dict):
+    items = getattr(field, "choices", None)
+    if items:
+        if isinstance(items, dict):  # pragma:nocover
             items = items.items()
 
         choices = []
@@ -254,7 +255,7 @@ class ModelTypeOptions(DjangoObjectTypeOptions):
     """Model type options for :class:`ModelType`."""
 
     #: If we shuld allow unauthenticated users to query for this model.
-    allow_unauthenticated: bool = False
+    public: bool = False
 
     #: A list of django permissions to check if the user has permission to
     #: query this model.
@@ -270,6 +271,9 @@ class ModelTypeOptions(DjangoObjectTypeOptions):
     #: If any object permission should allow the user to query this model.
     object_permissions_any: bool = True
 
+    #: If superuser should be considered when getting `GuardedModelManager.for_user`
+    object_permissions_with_superuser: bool = True
+
     #: The fields schema for the schema query
     fields_schema: Optional[dict] = None
 
@@ -293,8 +297,9 @@ class ModelType(_BaseDjangoObjectType, Generic[_T]):
         permissions_any=True,
         object_permissions=None,
         object_permissions_any=True,
+        object_permissions_with_superuser=True,
         fields_schema=None,
-        allow_unauthenticated=False,
+        public=None,
         only_fields=None,
         fields=None,
         exclude_fields=None,
@@ -304,11 +309,15 @@ class ModelType(_BaseDjangoObjectType, Generic[_T]):
         if not _meta:
             _meta = ModelTypeOptions(cls)
 
+        if "allow_unauthenticated" in kwargs:
+            raise ImproperlyConfigured("Use 'public' instead of 'allow_unauthenticated'")
+
         _meta.permissions = permissions or []
         _meta.permissions_any = permissions_any
         _meta.object_permissions = object_permissions or []
         _meta.object_permissions_any = object_permissions_any
-        _meta.allow_unauthenticated = allow_unauthenticated
+        _meta.object_permissions_with_superuser = object_permissions_with_superuser
+        _meta.public = public
 
         _fields_schema = {}
         # graphene will handle the deprecated only_fields/exclude_fields for us
@@ -373,17 +382,17 @@ class ModelType(_BaseDjangoObjectType, Generic[_T]):
                 info.context.user,
                 cls._meta.object_permissions,
                 any_perm=cls._meta.object_permissions_any,
+                with_superuser=cls._meta.object_permissions_with_superuser,
             )
 
         ret = super().get_queryset(qs, info)
-        if gql_optimizer is None:
-            return ret
-
-        ret = gql_optimizer.query(ret, info)
-        prl = {
-            i.to_attr if isinstance(i, Prefetch) else i: i for i in ret._prefetch_related_lookups
-        }
-        ret._prefetch_related_lookups = tuple(prl.values())
+        if gql_optimizer is not None:
+            ret = gql_optimizer.query(ret, info)
+            prl = {
+                i.to_attr if isinstance(i, Prefetch) else i: i  # type:ignore
+                for i in ret._prefetch_related_lookups
+            }
+            ret._prefetch_related_lookups = tuple(prl.values())
 
         return ret
 
@@ -417,7 +426,7 @@ class ModelType(_BaseDjangoObjectType, Generic[_T]):
         Subclasses can override this to avoid the permission checking or
         extending it. Remember to call `super()` in the later case.
         """
-        if not cls._meta.allow_unauthenticated and not check_authenticated(user):
+        if not cls._meta.public and not check_authenticated(user):
             return False
 
         if not cls._meta.permissions:
